/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is a test framework for NEON YUV-to-ARGB code.
 *
 * The Initial Developer of the Original Code is ARM Ltd.
 * Portions created by the Initial Developer are Copyright (C) 2011
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Jacob Bramley <Jacob.Bramley@arm.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include <stdio.h>
#include <stdint.h>
#include "framework.h"

// --------

extern void ScaleYCbCrToRGB565_Bilinear_NEON_jbramley_vtbl_asm(
    uint8_t const *  y,             // Buffer of source 'y' values.
    uint8_t const *  u,             // Buffer of source 'u' values.
    uint8_t const *  v,             // Buffer of source 'v' values.
    uint8_t       *  dst,           // Buffer for destination ARGB-8888 values.
    int              src_width,     // Source width.
    int              src_height,    // Source height.
    int              dst_width,     // Destination width.
    int              dst_height,    // Destination height.
    int              src_rowstride, // Source row-stride.
    int              dst_rowstride);// Destination row-stride.

// --------

void ScaleYCbCrToRGB565_Bilinear_NEON_jbramley_vtbl(
        uint8_t const * y,
        uint8_t const * u,
        uint8_t const * v,
        void          * rgb,
        int             src_left,
        int             src_top,
        int             src_width,
        int             src_height,
        int             dst_width,
        int             dst_height,
        int             y_pitch,    // Source row-stride.
        int             uv_pitch,   // Source row-stride for U and V.
        int             rgb_pitch,  // Destination row-stride.
        format_t        src_format)
{
    if (uv_pitch != y_pitch/2) {
        printf("Error: This routine cannot handle formats where uv_pitch is not y_pitch/2.\n");
        return;
    }

    // Adjust source pointers past the padding section.
    y += src_left + y_pitch * src_top;
    u += (src_left/2) + uv_pitch * (src_top/2);
    v += (src_left/2) + uv_pitch * (src_top/2);

    ScaleYCbCrToRGB565_Bilinear_NEON_jbramley_vtbl_asm(
            y, u, v, rgb,
            src_width,
            src_height,
            dst_width,
            dst_height,
            y_pitch,
            rgb_pitch);
}

